@@ -117,7 +117,12 @@ class Json4_Data
      */
     public static function error(string $code, string $string): string
     {
-        return json_encode(["error" => ["code" => $code, "message" => $string]], JSON_PRETTY_PRINT) ?: '';
+        return json_encode([
+            "error" => [
+                "code" => $code,
+                "message" => $string
+            ]
+        ], JSON_PRETTY_PRINT) ?: '';
     }
 
     /**
@@ -322,7 +327,6 @@ class Json4_Data
             if ($artist->isNew()) {
                 continue;
             }
-            $artist->format();
 
             $rating      = new Rating($artist->id, 'artist');
             $user_rating = $rating->get_user_rating($user->getId());
@@ -396,7 +400,6 @@ class Json4_Data
             if ($album->isNew()) {
                 continue;
             }
-            $album->format();
 
             $rating      = new Rating($album->id, 'album');
             $user_rating = $rating->get_user_rating($user->getId());
@@ -412,7 +415,7 @@ class Json4_Data
 
             if ($album->get_artist_fullname() != "") {
                 $objArray['artist'] = [
-                    "id" => (string)$album->album_artist,
+                    "id" => (string)$album->findAlbumArtist(),
                     "name" => $album->get_artist_fullname()
                 ];
             }
@@ -600,7 +603,6 @@ class Json4_Data
             if ($catalog === null) {
                 break;
             }
-            $catalog->format();
             $catalog_name           = $catalog->name;
             $catalog_type           = $catalog->catalog_type;
             $catalog_gather_types   = $catalog->gather_types;
@@ -608,7 +610,7 @@ class Json4_Data
             $catalog_last_add       = $catalog->get_f_add();
             $catalog_last_clean     = $catalog->get_f_clean();
             $catalog_last_update    = $catalog->get_f_update();
-            $catalog_path           = $catalog->f_info;
+            $catalog_path           = $catalog->get_f_info();
             $catalog_rename_pattern = $catalog->rename_pattern;
             $catalog_sort_pattern   = $catalog->sort_pattern;
             // Build this element
@@ -722,7 +724,7 @@ class Json4_Data
             if ($episode->isNew()) {
                 continue;
             }
-            $episode->format();
+
             $rating      = new Rating($episode->id, 'podcast_episode');
             $user_rating = $rating->get_user_rating($user->getId());
             $flag        = new Userflag($episode->id, 'podcast_episode');
@@ -790,7 +792,7 @@ class Json4_Data
                 continue;
             }
 
-            $song->format();
+            $song->fill_ext_info();
             $rating      = new Rating($song->id, 'song');
             $user_rating = $rating->get_user_rating($user->getId());
             $flag        = new Userflag($song->id, 'song');
@@ -897,7 +899,6 @@ class Json4_Data
             if ($video->isNew()) {
                 continue;
             }
-            $video->format();
             $rating      = new Rating($video->id, 'video');
             $user_rating = $rating->get_user_rating($user->getId());
             $flag        = new Userflag($video->id, 'video');
@@ -906,7 +907,7 @@ class Json4_Data
                 "id" => (string)$video->id,
                 "title" => $video->title,
                 "mime" => $video->mime,
-                "resolution" => $video->f_resolution,
+                "resolution" => $video->get_f_resolution(),
                 "size" => (int)$video->size,
                 "tag" => self::tags_array($video->get_tags()),
                 "time" => (int)$video->time,
@@ -948,7 +949,7 @@ class Json4_Data
             if ($song->isNew()) {
                 continue;
             }
-            $song->format();
+            $song->fill_ext_info();
 
             $rating      = new Rating($song->id, 'song');
             $user_rating = $rating->get_user_rating($user->getId());
@@ -959,8 +960,14 @@ class Json4_Data
             $JSON[] = [
                 "id" => (string)$song->id,
                 "title" => $song->title,
-                "artist" => ["id" => (string)$song->artist, "name" => $song->get_artist_fullname()],
-                "album" => ["id" => (string)$song->album, "name" => $song->get_album_fullname()],
+                "artist" => [
+                    "id" => (string)$song->artist,
+                    "name" => $song->get_artist_fullname()
+                ],
+                "album" => [
+                    "id" => (string)$song->album,
+                    "name" => $song->get_album_fullname()
+                ],
                 "tag" => self::tags_array($song->get_tags()),
                 "track" => (int)$song->track,
                 "time" => (int)$song->time,
@@ -987,7 +994,6 @@ class Json4_Data
     public static function user(User $user, bool $fullinfo): string
     {
         $JSON = [];
-        $user->format();
         if ($fullinfo) {
             $JSON['user'] = [
                 "id" => (string) $user->getId(),
