@@ -53,13 +53,20 @@ use Exception;
  */
 class Catalog_local extends Catalog
 {
-    private string $version     = '000001';
-    private string $type        = 'local';
+    private string $version = '000001';
+
+    private string $type = 'local';
+
     private string $description = 'Local Catalog';
 
     private int $catalog_id;
-    private int $count              = 0;
-    private array $songs_to_gather  = [];
+
+    private int $count = 0;
+
+    /** @var int[] $songs_to_gather */
+    private array $songs_to_gather = [];
+
+    /** @var int[] $videos_to_gather */
     private array $videos_to_gather = [];
 
     public string $path = '';
@@ -214,13 +221,14 @@ class Catalog_local extends Catalog
      * This creates a new catalog type entry for a catalog
      * It checks to make sure its parameters is not already used before creating
      * the catalog.
-     * @param string $catalog_id
-     * @param array $data
+     * @param array{
+     *     path?: string,
+     * } $data
      */
-    public static function create_type($catalog_id, $data): bool
+    public static function create_type(string $catalog_id, array $data): bool
     {
         // Clean up the path just in case
-        $path = rtrim(rtrim(trim($data['path']), '/'), '\\');
+        $path = rtrim(rtrim(trim($data['path'] ?? ''), '/'), '\\');
 
         if (!self::check_path($path)) {
             AmpError::add('general', T_('Path was not specified'));
@@ -252,11 +260,9 @@ class Catalog_local extends Catalog
      * Recurses through $this->path and pulls out all mp3s and returns the
      * full path in an array. Passes gather_type to determine if we need to
      * check id3 information against the db.
-     * @param string $path
-     * @param array $options
-     * @param int $counter
+     * @param array<string, mixed> $options
      */
-    public function add_files($path, $options, $counter = 0, ?Interactor $interactor = null): int
+    public function add_files(string $path, array $options, int $counter = 0, ?Interactor $interactor = null): int
     {
         // See if we want a non-root path for the add
         if (isset($options['subdirectory'])) {
@@ -321,8 +327,16 @@ class Catalog_local extends Catalog
 
             /* Create the new path */
             $full_file = $path . $slash_type . $file;
-            if ($this->add_file($full_file, $options, $counter, $interactor)) {
-                $songsadded++;
+            try {
+                if ($this->add_file($full_file, $options, $counter, $interactor)) {
+                    $songsadded++;
+                }
+            } catch (Exception $error) {
+                $interactor?->info(
+                    T_('Error') . ' ' . $error->getMessage(),
+                    true
+                );
+                debug_event('local.catalog', 'add_file error: ' . $error->getMessage(), 1);
             }
         } // end while reading directory
 
@@ -345,14 +359,9 @@ class Catalog_local extends Catalog
 
     /**
      * add_file
-     *
-     * @param string $full_file
-     * @param array $options
-     * @param int $counter
-     * @return bool
      * @throws Exception
      */
-    public function add_file($full_file, $options, $counter = 0, ?Interactor $interactor = null): bool
+    public function add_file(string $full_file, array $options, int $counter = 0, ?Interactor $interactor = null): bool
     {
         // Ensure that we've got our cache
         $this->_create_filecache();
@@ -488,7 +497,7 @@ class Catalog_local extends Catalog
                 if (count($this->get_gather_types('music')) > 0) {
                     if ($is_audio_file && $this->_insert_local_song($full_file, $options)) {
                         $interactor?->info(
-                            'Imported song file: ' . $full_file,
+                            T_('Added') . ' ' . $full_file,
                             true
                         );
                         debug_event('local.catalog', 'Imported song file: ' . $full_file, 5);
@@ -504,7 +513,7 @@ class Catalog_local extends Catalog
                 } elseif (count($this->get_gather_types('video')) > 0) {
                     if ($is_video_file && $this->_insert_local_video($full_file, $options)) {
                         $interactor?->info(
-                            'Imported video file: ' . $full_file,
+                            T_('Added') . ' ' . $full_file,
                             true
                         );
                         debug_event('local.catalog', 'Imported video file: ' . $full_file, 5);
@@ -670,16 +679,19 @@ class Catalog_local extends Catalog
             'Verify starting on ' . $this->name,
             true
         );
-        debug_event('local.catalog', 'Verify starting on ' . $this->name, 5);
         set_time_limit(0);
 
-        $date        = time();
         $this->count = 0;
         $chunk_size  = 10000;
 
+        debug_event('local.catalog', 'Verify starting on ' . $this->name . ' (' . time() . ')', 5);
+        sleep(1);
+
+        $last_update     = true;
         $gather_type     = $this->gather_types;
         $verify_by_album = AmpConfig::get('catalog_verify_by_album', false);
-        $update_time     = ($gather_type !== 'podcast' && AmpConfig::get('catalog_verify_by_time', false))
+        $verify_by_time  = ($gather_type !== 'album' && AmpConfig::get('catalog_verify_by_time', false));
+        $update_time     = ($verify_by_time)
             ? $this->last_update
             : 0;
         if (!$verify_by_album && $gather_type == 'music') {
@@ -702,13 +714,25 @@ class Catalog_local extends Catalog
         } else {
             return $this->count;
         }
+
+        // count with no limit after 0
+        if ($total === 0 && ($update_time > 0 || $limit > 0)) {
+            $last_update = false;
+            $total       = self::count_table($media_type, $this->catalog_id);
+        }
+
         $count  = 1;
         $chunks = 1;
         $chunk  = 0;
+
         // how many loops through the catalog
         if ($total > $chunk_size) {
             $chunks = (int)ceil($total / $chunk_size);
         }
+        // one loop
+        if ($total < $chunk_size) {
+            $chunk = 1;
+        }
 
         // only do the requested size
         if ($limit > 0 && $total < $chunk_size) {
@@ -718,17 +742,17 @@ class Catalog_local extends Catalog
         }
 
         $interactor?->info(
-            'found ' . $total . " " . $media_type . " files to update. (last_update: " . $this->last_update . ")",
+            sprintf(T_('File count: %d'), $total) . ' (last_update: ' . $this->last_update . ')',
             true
         );
-        debug_event('local.catalog', 'found ' . $total . " " . $media_type . " files to update. (last_update: " . $this->last_update . ")", 5);
+        debug_event('local.catalog', sprintf(T_('File count: %d'), $total) . ' (last_update: ' . $this->last_update . ')', 5);
         while ($count <= $chunks) {
             $interactor?->info(
                 "catalog " . $this->name . " starting verify " . $media_type . " on chunk $count/$chunks",
                 true
             );
             debug_event('local.catalog', "catalog " . $this->name . " starting verify " . $media_type . " on chunk $count/$chunks", 5);
-            $this->count += $this->_verify_chunk($media_type, ($chunks - $chunk), $chunk_size);
+            $this->count += $this->_verify_chunk($media_type, ($chunks - $chunk), $chunk_size, $verify_by_time, $last_update);
             $chunk++;
             $count++;
             if ($media_type === 'song') {
@@ -749,9 +773,10 @@ class Catalog_local extends Catalog
             $this->getAlbumRepository()->collectGarbage();
         }
 
+        sleep(1);
         // No limit set OR we set a limit and we didn't find anything so update the last_update time
-        if ($limit === 0 || ($update_time > 0 && $total === 0)) {
-            $this->update_last_update($date);
+        if ($limit === 0 || $last_update === false) {
+            $this->update_last_update(time());
         }
 
         return $this->count;
@@ -764,19 +789,19 @@ class Catalog_local extends Catalog
      * @param string $tableName ('album', 'podcast_episode', 'song', 'video')
      * @param int $chunk
      * @param int $chunk_size
+     * @param bool $verify_by_time
+     * @param bool $last_update
      */
-    private function _verify_chunk($tableName, $chunk, $chunk_size): int
+    private function _verify_chunk($tableName, $chunk, $chunk_size, $verify_by_time, $last_update): int
     {
-        $verify_by_time = $tableName !== 'podcast_episode' && AmpConfig::get('catalog_verify_by_time', false);
-        $count          = $chunk * $chunk_size;
-        $sql            = match ($tableName) {
-            'album' => ($verify_by_time)
-                ? "SELECT `album`.`id`, MIN(`song`.`file`) AS `file`, MIN(`song`.`update_time`) AS `min_update_time` FROM `album` LEFT JOIN `song` ON `song`.`album` = `album`.`id` WHERE `album`.`catalog` = ? AND song.update_time < " . $this->last_update . " GROUP BY `album`.`id` ORDER BY MIN(`song`.`file`) DESC LIMIT $count, $chunk_size"
-                : "SELECT `album`.`id`, MIN(`song`.`file`) AS `file`, MIN(`song`.`update_time`) AS `min_update_time` FROM `album` LEFT JOIN `song` ON `song`.`album` = `album`.`id` WHERE `album`.`catalog` = ? GROUP BY `album`.`id` ORDER BY MIN(`song`.`file`) DESC $count, $chunk_size",
-            'podcast_episode' => "SELECT `podcast_episode`.`id`, `podcast_episode`.`file` FROM `podcast_episode` LEFT JOIN `catalog` ON `podcast_episode`.`catalog` = `catalog`.`id` WHERE `podcast_episode`.`catalog` = ? AND `podcast_episode`.`file` IS NOT NULL ORDER BY `podcast_episode`.`podcast`, `podcast_episode`.`pubdate` DESC LIMIT $count, $chunk_size",
-            default => ($verify_by_time)
-                ? "SELECT `$tableName`.`id`, `$tableName`.`file`, `$tableName`.`update_time` AS `min_update_time` FROM `$tableName` LEFT JOIN `catalog` ON `$tableName`.`catalog` = `catalog`.`id` WHERE `$tableName`.`catalog` = ? AND (`$tableName`.`update_time` IS NULL OR `$tableName`.`update_time` < `catalog`.`last_update`) ORDER BY `$tableName`.`file` DESC LIMIT $count, $chunk_size"
-                : "SELECT `$tableName`.`id`, `$tableName`.`file` FROM `$tableName` LEFT JOIN `catalog` ON `$tableName`.`catalog` = `catalog`.`id` WHERE `$tableName`.`catalog` = ? ORDER BY `$tableName`.`file` LIMIT $count, $chunk_size",
+        $count = $chunk * $chunk_size;
+        $sql   = match ($tableName) {
+            'album' => ($last_update)
+                ? "SELECT `album`.`id`, MIN(`song`.`file`) AS `file`, MIN(`song`.`update_time`) AS `min_update_time` FROM `album` LEFT JOIN `song` ON `song`.`album` = `album`.`id` WHERE `album`.`catalog` = ? AND song.update_time < " . $this->last_update . " GROUP BY `album`.`id` ORDER BY MIN(`song`.`file`) DESC LIMIT $chunk_size"
+                : "SELECT `album`.`id`, MIN(`song`.`file`) AS `file`, MIN(`song`.`update_time`) AS `min_update_time` FROM `album` LEFT JOIN `song` ON `song`.`album` = `album`.`id` WHERE `album`.`catalog` = ? GROUP BY `album`.`id` ORDER BY MIN(`song`.`file`) DESC LIMIT $chunk_size",
+            default => ($last_update)
+                ? "SELECT `$tableName`.`id`, `$tableName`.`file`, `$tableName`.`update_time` AS `min_update_time` FROM `$tableName` LEFT JOIN `catalog` ON `$tableName`.`catalog` = `catalog`.`id` WHERE `$tableName`.`catalog` = ? AND `$tableName`.`update_time` < `catalog`.`last_update` ORDER BY `$tableName`.`file` DESC LIMIT $chunk_size"
+                : "SELECT `$tableName`.`id`, `$tableName`.`file`, `$tableName`.`update_time` AS `min_update_time` FROM `$tableName` LEFT JOIN `catalog` ON `$tableName`.`catalog` = `catalog`.`id` WHERE `$tableName`.`catalog` = ? ORDER BY `$tableName`.`file` DESC LIMIT $chunk_size",
         };
 
         //debug_event(self::class, '_verify_chunk (' . $chunk . ') ' . $sql. ' ' . print_r($params, true), 5);
@@ -801,14 +826,59 @@ class Catalog_local extends Catalog
                 Ui::update_text('verify_dir_' . $this->catalog_id, scrub_out($file));
             }
 
-            if (
-                $tableName !== 'album' &&
-                !Core::is_readable(Core::conv_lc_file((string)$row['file']))
-            ) {
-                /* HINT: filename (file path) */
-                AmpError::add('general', sprintf(T_("The file couldn't be read. Does it exist? %s"), $row['file']));
-                debug_event('local.catalog', $row['file'] . ' does not exist or is not readable', 5);
-                continue;
+            if ($tableName !== 'album') {
+                if (!Core::is_readable(Core::conv_lc_file((string)$row['file']))) {
+                    /* HINT: filename (file path) */
+                    AmpError::add('general', sprintf(T_("The file couldn't be read. Does it exist? %s"), $row['file']));
+                    debug_event('local.catalog', $row['file'] . ' does not exist or is not readable', 5);
+                    switch ($tableName) {
+                        case 'song':
+                            Song::update_utime($row['id']);
+                            break;
+                        case 'video':
+                            Video::update_utime($row['id']);
+                            break;
+                        case 'podcast_episode':
+                            Podcast_Episode::update_utime($row['id']);
+                            break;
+                    }
+                    continue;
+                }
+
+                if ($verify_by_time) {
+                    $file_time = filemtime($row['file']);
+                    if ($file_time === false) {
+                        debug_event('local.catalog', 'Unable to get file modification time for ' . $row['file'], 3);
+                        switch ($tableName) {
+                            case 'song':
+                                Song::update_utime($row['id']);
+                                break;
+                            case 'video':
+                                Video::update_utime($row['id']);
+                                break;
+                            case 'podcast_episode':
+                                Podcast_Episode::update_utime($row['id']);
+                                break;
+                        }
+                        continue;
+                    }
+                    // check the modification time on the file to see if it's worth checking the tags.
+                    if ((int)($row['min_update_time'] ?? 0) > $file_time) {
+                        //debug_event('local.catalog', 'verify_by_time: skipping ' . $row['file'], 5);
+                        switch ($tableName) {
+                            case 'song':
+                                Song::update_utime($row['id']);
+                                break;
+                            case 'video':
+                                Video::update_utime($row['id']);
+                                break;
+                            case 'podcast_episode':
+                                Podcast_Episode::update_utime($row['id']);
+                                break;
+                        }
+                        continue;
+                    }
+                }
             }
 
             if (self::update_single_item($tableName, $row['id'], true, true)['change']) {
@@ -840,6 +910,7 @@ class Catalog_local extends Catalog
 
             return 0;
         }
+
         $this->count = 0;
 
         $gather_type = $this->gather_types;
@@ -866,7 +937,7 @@ class Catalog_local extends Catalog
                 true
             );
             debug_event('local.catalog', "catalog " . $this->name . " Starting clean " . $media_type . " on chunk $count/$chunks", 5);
-            $dead = array_merge($dead, $this->_clean_chunk($media_type, $chunk, 10000));
+            $dead = array_merge($dead, $this->_clean_chunk($media_type, $chunk, 10000, $interactor));
             $chunk++;
             $count++;
         }
@@ -906,7 +977,7 @@ class Catalog_local extends Catalog
      * This is the clean function and is broken into chunks to try to save a little memory
      * @return list<int>
      */
-    private function _clean_chunk(string $media_type, int $chunk, int $chunk_size): array
+    private function _clean_chunk(string $media_type, int $chunk, int $chunk_size, ?Interactor $interactor = null): array
     {
         $dead  = [];
         $count = $chunk * $chunk_size;
@@ -922,6 +993,10 @@ class Catalog_local extends Catalog
                 Ui::update_text('clean_dir_' . $this->catalog_id, scrub_out($file));
             }
             if ($this->clean_file($results['file'], $media_type)) {
+                $interactor?->info(
+                    'File removed: ' . $results['file'],
+                    true
+                );
                 $dead[] = $results['id'];
             }
         }
@@ -934,7 +1009,7 @@ class Catalog_local extends Catalog
      * This is the check function and is broken into chunks to try to save a little memory
      * @return list<string>
      */
-    private function _check_chunk(string $media_type, int $chunk, int $chunk_size): array
+    private function _check_chunk(string $media_type, int $chunk, int $chunk_size, ?Interactor $interactor = null): array
     {
         $missing = [];
         $count   = $chunk * $chunk_size;
@@ -945,9 +1020,17 @@ class Catalog_local extends Catalog
         while ($results = Dba::fetch_assoc($db_results)) {
             $file_info = Core::get_filesize(Core::conv_lc_file($results['file']));
             if ($file_info < 1) {
+                $interactor?->info(
+                    'File not found or empty: ' . $results['file'],
+                    true
+                );
                 debug_event('local.catalog', '_clean_chunk: {' . $results['id'] . '} File not found or empty ' . $results['file'], 5);
                 $missing[] = $results['file'];
             } elseif (!Core::is_readable(Core::conv_lc_file((string)$results['file']))) {
+                $interactor?->info(
+                    $results['file'] . ' is not readable, but does exist',
+                    true
+                );
                 debug_event('local.catalog', "_clean_chunk: " . $results['file'] . ' is not readable, but does exist', 1);
             }
         }
@@ -1206,11 +1289,11 @@ class Catalog_local extends Catalog
     }
 
     /**
-     * format
+     * get_f_info
      */
-    public function format(): void
+    public function get_f_info(): string
     {
-        $this->f_info = $this->path;
+        return $this->path;
     }
 
     /**
@@ -1269,7 +1352,7 @@ class Catalog_local extends Catalog
     /**
      * @return string[]
      */
-    public function check_catalog_proc(): array
+    public function check_catalog_proc(?Interactor $interactor = null): array
     {
         if (!Core::is_readable($this->path)) {
             // First sanity check; no point in proceeding with an unreadable catalog root.
@@ -1295,7 +1378,7 @@ class Catalog_local extends Catalog
         $chunks = (int)ceil($total / 10000);
         foreach (range(1, $chunks) as $chunk) {
             debug_event('local.catalog', "catalog " . $this->name . " Starting check " . $media_type . " on chunk $chunk/$chunks", 5);
-            $missing = array_merge($missing, $this->_check_chunk($media_type, (int)$chunk, 10000));
+            $missing = array_merge($missing, $this->_check_chunk($media_type, (int)$chunk, 10000, $interactor));
         }
 
         return $missing;
