@@ -480,7 +480,7 @@ final class SongSearch implements SearchInterface
                         $table['rating'] = '';
                     }
                     $table['rating'] .= (!strpos((string) $table['rating'], "rating_" . $my_type . "_" . $search_user_id))
-                        ? "LEFT JOIN (SELECT `object_id`, `object_type`, `rating` FROM `rating` WHERE `user` = " . $search_user_id . " AND `object_type`='$my_type') AS `rating_" . $my_type . "_" . $search_user_id . "` ON `rating_" . $my_type . "_" . $search_user_id . "`.`object_id` = `song`.`$column`"
+                        ? "LEFT JOIN (SELECT `object_id`, `object_type`, `rating` FROM `rating` WHERE `user` = " . $search_user_id . " AND `object_type` = '$my_type') AS `rating_" . $my_type . "_" . $search_user_id . "` ON `rating_" . $my_type . "_" . $search_user_id . "`.`object_id` = `song`.`$column`"
                         : "";
                     break;
                 case 'my_flagged':
@@ -525,7 +525,7 @@ final class SongSearch implements SearchInterface
                             $table['rating'] = '';
                         }
                         $table['rating'] .= (!strpos((string) $table['rating'], "rating_" . $my_type . "_" . $other_userid))
-                            ? "LEFT JOIN `rating` AS `rating_" . $my_type . "_" . $other_userid . "` ON `rating_" . $my_type . "_" . $other_userid . "`.`object_type`='$my_type' AND `rating_" . $my_type . "_" . $other_userid . "`.`object_id` = `song`.`$column` AND `rating_" . $my_type . "_" . $other_userid . "`.`user` = $other_userid "
+                            ? "LEFT JOIN `rating` AS `rating_" . $my_type . "_" . $other_userid . "` ON `rating_" . $my_type . "_" . $other_userid . "`.`object_type` = '$my_type' AND `rating_" . $my_type . "_" . $other_userid . "`.`object_id` = `song`.`$column` AND `rating_" . $my_type . "_" . $other_userid . "`.`user` = $other_userid "
                             : "";
                     }
                     break;
@@ -535,9 +535,8 @@ final class SongSearch implements SearchInterface
                     } else {
                         $where[] = "`playlist`.`name` $operator_sql ?";
                     }
-                    $parameters[]          = $input;
-                    $join['playlist']      = true;
-                    $join['playlist_data'] = true;
+                    $parameters[]     = $input;
+                    $join['playlist'] = true;
                     break;
                 case 'playlist':
                     $where[]      = "`song`.`id` $operator_sql IN (SELECT `object_id` FROM `playlist_data` WHERE `playlist_data`.`playlist` = ? AND `playlist_data`.`object_type` = 'song')";
@@ -547,12 +546,10 @@ final class SongSearch implements SearchInterface
                     //debug_event(self::class, '_get_sql_song: SUBSEARCH ' . $input, 5);
                     $subsearch = new Search((int)$input, 'song', $search->search_user);
                     $results   = $subsearch->get_subsearch('song');
-                    if (!empty($results)) {
-                        $subsearch_count++;
-                        $where[] = "`song`.`id` $operator_sql IN (SELECT * FROM (" . $results['sql'] . ") AS sp_" . $subsearch_count . ")";
-                        foreach ($results['parameters'] as $parameter) {
-                            $parameters[] = $parameter;
-                        }
+                    $subsearch_count++;
+                    $where[] = "`song`.`id` $operator_sql IN (SELECT * FROM (" . $results['sql'] . ") AS sp_" . $subsearch_count . ")";
+                    foreach ($results['parameters'] as $parameter) {
+                        $parameters[] = $parameter;
                     }
                     break;
                 case 'added':
@@ -690,11 +687,8 @@ final class SongSearch implements SearchInterface
         if (array_key_exists('song_data', $join)) {
             $table['song_data'] = "LEFT JOIN `song_data` ON `song`.`id` = `song_data`.`song_id`";
         }
-        if (array_key_exists('playlist_data', $join)) {
-            $table['playlist_data'] = "LEFT JOIN `playlist_data` ON `song`.`id` = `playlist_data`.`object_id` AND `playlist_data`.`object_type`='song'";
-            if (array_key_exists('playlist', $join)) {
-                $table['playlist'] = "LEFT JOIN `playlist` ON `playlist_data`.`playlist` = `playlist`.`id`";
-            }
+        if (array_key_exists('playlist', $join)) {
+            $table['playlist'] = "LEFT JOIN `playlist_data` ON `song`.`id` = `playlist_data`.`object_id` AND `playlist_data`.`object_type`='song' LEFT JOIN `playlist` ON `playlist_data`.`playlist` = `playlist`.`id`";
         }
         if ($join['catalog']) {
             $table['1_catalog'] = "LEFT JOIN `catalog` AS `catalog_se` ON `catalog_se`.`id` = `song`.`catalog`";
