@@ -83,6 +83,8 @@ class Podcast_Episode extends database_object implements
 
     public int $addition_time;
 
+    public int $update_time;
+
     public int $total_count;
 
     public int $total_skip;
@@ -163,28 +165,6 @@ class Podcast_Episode extends database_object implements
         return $this->catalog;
     }
 
-    /**
-     * format
-     * this function takes the object and formats some values
-     */
-    public function format(): void
-    {
-        if ($this->isNew()) {
-            return;
-        }
-
-        // format the file
-        if (
-            $this->file !== null &&
-            $this->file !== '' &&
-            $this->file !== '0'
-        ) {
-            $this->type    = strtolower(pathinfo($this->file, PATHINFO_EXTENSION));
-            $this->mime    = Song::type_to_mime($this->type);
-            $this->enabled = true;
-        }
-    }
-
     public function getCategory(): string
     {
         return scrub_out($this->category);
@@ -332,14 +312,6 @@ class Podcast_Episode extends database_object implements
         return $this->podcast_link;
     }
 
-    /**
-     * get_f_artist_link
-     */
-    public function get_f_artist_link(): ?string
-    {
-        return $this->getPodcastLink();
-    }
-
     /**
      * Get item get_f_album_link.
      */
@@ -367,6 +339,9 @@ class Podcast_Episode extends database_object implements
         ];
     }
 
+    /**
+     * @return array{string?: list<array{object_type: LibraryItemEnum, object_id: int}>}
+     */
     public function get_childrens(): array
     {
         return [];
@@ -375,8 +350,9 @@ class Podcast_Episode extends database_object implements
     /**
      * Search for direct children of an object
      * @param string $name
+     * @return list<array{object_type: LibraryItemEnum, object_id: int}>
      */
-    public function get_children($name): array
+    public function get_children(string $name): array
     {
         debug_event(self::class, 'get_children ' . $name, 5);
 
@@ -434,10 +410,9 @@ class Podcast_Episode extends database_object implements
 
     /**
      * display_art
-     * @param int $thumb
-     * @param bool $force
+     * @param array{width: int, height: int} $size
      */
-    public function display_art($thumb = 2, $force = false): void
+    public function display_art(array $size, bool $force = false): void
     {
         $episode_id = null;
         $type       = null;
@@ -451,7 +426,7 @@ class Podcast_Episode extends database_object implements
         }
 
         if ($episode_id !== null && $type !== null) {
-            Art::display($type, $episode_id, (string)$this->get_fullname(), $thumb, $this->get_link());
+            Art::display($type, $episode_id, (string)$this->get_fullname(), $size, $this->get_link());
         }
     }
 
@@ -528,6 +503,21 @@ class Podcast_Episode extends database_object implements
         return Stats::has_played_history('podcast_episode', $this, $user, $agent, $date);
     }
 
+
+    /**
+     * update_utime
+     * sets a new update time
+     */
+    public static function update_utime(int $episode_id, int $time = 0): void
+    {
+        if (!$time) {
+            $time = time();
+        }
+
+        $sql = "UPDATE `podcast_episode` SET `update_time` = ? WHERE `id` = ?;";
+        Dba::write($sql, [$time, $episode_id]);
+    }
+
     /**
      * update_file
      * sets the file path
@@ -634,10 +624,9 @@ class Podcast_Episode extends database_object implements
 
     /**
      * Get stream types.
-     * @param null|string $player
      * @return list<string>
      */
-    public function get_stream_types($player = null): array
+    public function get_stream_types(?string $player = null): array
     {
         return Stream::get_stream_types_for_type($this->type, $player);
     }
